@@ -13,12 +13,19 @@
  * For license terms, see the file COPYING.
  */
 
+#ifndef S_SPLINT_S
 #include <unistd.h>
-#include <stdio.h>
 #include <ctype.h>
+#endif /* S_SPLINT_S */
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdbool.h>
+#include <getopt.h>
+
+#ifdef __CYGWIN__
+#undef stricmp
+#endif /* __CYGWIN__ */
 
 typedef char	*string;
 
@@ -94,7 +101,7 @@ static void process_options(int argc, char *argv[], char * opt_string)
 	    help = true;
 	    break;
 	case 'v':
-	    printf("ascii %2.1f\n",REVISION); 
+	    printf("ascii %3.2f\n",REVISION);
 	    exit(0);
 	default :
 	    help = true;
@@ -234,7 +241,7 @@ static void ascii(char *str)
     { speak((unsigned int)(str[1] & 0x1f)); return; }
 
     /* interpret C-style backslash escapes */
-    if (*str == '\\' &&  len == 2 && strchr("abfnrtv", str[1]))
+    if (*str == '\\' &&  len == 2 && strchr("abfnrtv0", str[1]))
 	for (ch = 7; ch < 14; ch++)
 	    for (ptr = &cnames[ch][1]; *ptr; ptr++)
 		if (**ptr == '\\' && strcmp(str, *ptr) == 0)
@@ -396,6 +403,5 @@ int main(int argc, char **argv)
     exit(0);
 }
 
-/******************************************************************/
 /* ascii.c ends here */
 
